#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_RSQRT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_RSQRT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/rsqrt.hpp>

#endif
